@@ -17,7 +17,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301  USA
+ * Boston, MA  02110-1301  USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -72,6 +72,12 @@ on_about_activate (GtkMenuItem *menuitem, gpointer user_data)
 		NULL
 	};
 
+	const gchar* documenters[] = {
+		"Fabio Marzocca <thesaltydog@gmail.com>",
+		N_("MATE Documentation Team"),
+		NULL,
+	};
+
 	const gchar* license[] = {
 		N_("This program is free software; you can redistribute it and/or "
 		"modify it under the terms of the GNU General Public License as "
@@ -85,20 +91,29 @@ on_about_activate (GtkMenuItem *menuitem, gpointer user_data)
 
 		N_("You should have received a copy of the GNU General Public License "
 		"along with this program; if not, write to the Free Software Foundation, Inc., 51 "
-		"Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA")
+		"Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.")
 	};
 
 
 	gchar* license_trans = g_strjoin("\n\n", _(license[0]), _(license[1]), _(license[2]), NULL);
 
+#ifdef ENABLE_NLS
+	const char **p;
+	for (p = documenters; *p; ++p)
+		*p = _(*p);
+#endif
+
 	gtk_show_about_dialog (GTK_WINDOW (baobab.window),
-		"comments", _("A graphical tool to analyze disk usage."),
+		"program-name", _("Disk Usage Analyzer"),
 		"version", VERSION,
+		"title", _("About Disk Usage Analyzer"),
+		"comments", _("A graphical tool to analyze disk usage."),
 		"copyright", _("Copyright \xc2\xa9 2005-2010 Fabio Marzocca\n"
 		               "Copyright \xc2\xa9 2011-2019 MATE developers"),
 		"logo-icon-name", "mate-disk-usage-analyzer",
 		"license", license_trans,
 		"authors", authors,
+		"documenters", documenters,
 		"translator-credits", _("translator-credits"),
 		"wrap-license", TRUE,
 		NULL);
