@@ -763,9 +763,16 @@ logview_about (GtkWidget *widget, GtkWidget *window)
                                    _(logview_about_license[1]),
                                    _(logview_about_license[2]), NULL);
 
+#ifdef ENABLE_NLS
+  const char **p;
+  for (p = logview_about_documenters; *p; ++p)
+    *p = _(*p);
+#endif
+
   gtk_show_about_dialog (GTK_WINDOW (window),
-                         "name",  _("System Log Viewer"),
+                         "program-name", _("System Log Viewer"),
                          "version", VERSION,
+                         "title", _("About System Log Viewer"),
                          "copyright", _("Copyright \xc2\xa9 1998-2008 Free Software Foundation, Inc.\n"
                                         "Copyright \xc2\xa9 2011-2019 MATE developers"),
                          "license", license_trans,
