@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
  */
 
 /**
@@ -244,7 +244,7 @@ gdict_source_class_init (GdictSourceClass *klass)
   				   PROP_NAME,
   				   g_param_spec_string ("name",
   				   			_("Name"),
-  				   			_("The display name of this dictonary source"),
+  				   			_("The display name of this dictionary source"),
   				   			NULL,
   				   			(G_PARAM_READABLE | G_PARAM_WRITABLE)));
   /**
@@ -272,7 +272,7 @@ gdict_source_class_init (GdictSourceClass *klass)
   				   PROP_DATABASE,
   				   g_param_spec_string ("database",
   				   			_("Database"),
-  				   			_("The default database of this dictonary source"),
+  				   			_("The default database of this dictionary source"),
   				   			NULL,
   				   			(G_PARAM_READABLE | G_PARAM_WRITABLE)));
   /**
@@ -286,7 +286,7 @@ gdict_source_class_init (GdictSourceClass *klass)
   				   PROP_STRATEGY,
   				   g_param_spec_string ("strategy",
   				   			_("Strategy"),
-  				   			_("The default strategy of this dictonary source"),
+  				   			_("The default strategy of this dictionary source"),
   				   			NULL,
   				   			(G_PARAM_READABLE | G_PARAM_WRITABLE)));
   /**
