@@ -46,36 +46,47 @@ gdict_show_about_dialog (GtkWidget *parent)
   };
 
   const gchar *documenters[] = {
-    "Sun GNOME Documentation Team <gdocteam@sun.com>",
+    N_("Sun GNOME Documentation Team <gdocteam@sun.com>"),
     "John Fleck <jfleck@inkstain.net>",
     "Emmanuele Bassi <ebassi@gmail.com>",
+    N_("MATE Documentation Team"),
     NULL
   };
 
   const gchar *translator_credits = _("translator-credits");
   const gchar *comments = _("Look up words in dictionaries");
-  
-  const gchar *license =
-    "This program is free software; you can redistribute it and/or "
-    "modify it under the terms of the GNU General Public License as "
-    "published by the Free Software Foundation; either version 2 of "
-    "the License, or (at your option) any later version.\n"
-    "\n"
-    "This program is distributed in the hope that it will be useful, "
-    "but WITHOUT ANY WARRANTY; without even the implied warranty of "
-    "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU "
-    "General Public License for more details.\n"
-    "\n"
-    "You should have received a copy of the GNU General Public License "
-    "along with this program; if not, write to the Free Software "
-    "Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA "
-    "02110-1301, USA.\n";
+
+  const gchar* license[] = {
+    N_("This program is free software; you can redistribute it and/or "
+       "modify it under the terms of the GNU General Public License as "
+       "published by the Free Software Foundation; either version 2 of "
+       "the License, or (at your option) any later version."),
+
+    N_("This program is distributed in the hope that it will be useful, "
+       "but WITHOUT ANY WARRANTY; without even the implied warranty of "
+       "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU "
+       "General Public License for more details."),
+
+    N_("You should have received a copy of the GNU General Public License "
+       "along with this program; if not, write to the Free Software "
+       "Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA "
+       "02110-1301, USA.")
+  };
 
   g_return_if_fail (GTK_IS_WIDGET (parent));
-  
+
+  char *license_trans = g_strjoin ("\n\n", _(license[0]), _(license[1]), _(license[2]), NULL);
+
+#ifdef ENABLE_NLS
+  const char **p;
+  for (p = documenters; *p; ++p)
+    *p = _(*p);
+#endif
+
   gtk_show_about_dialog (GTK_IS_WINDOW (parent) ? GTK_WINDOW (parent) : NULL,
-  			 "name", _("Dictionary"),
+			 "program-name", _("Dictionary"),
   			 "version", VERSION,
+			 "title", _("About Dictionary"),
 			 "copyright", _("Copyright \xc2\xa9 2005-2006 Emmanuele Bassi\n"
 			                "Copyright \xc2\xa9 2011-2019 MATE developers"),
   			 "comments", comments,
@@ -83,8 +94,10 @@ gdict_show_about_dialog (GtkWidget *parent)
   			 "documenters", documenters,
   			 "translator-credits", translator_credits,
   			 "logo-icon-name", "accessories-dictionary",
-  			 "license", license,
+			 "license", license_trans,
   			 "wrap-license", TRUE,
 			 "screen", gtk_widget_get_screen (parent),
   			 NULL);
+
+  g_free(license_trans);
 }
