@@ -96,8 +96,11 @@ static char *last_save_dir = NULL;
 static char *temporary_file = NULL;
 static gboolean save_immediately = FALSE;
 static GSettings *settings = NULL;
+static gboolean interactive_arg = FALSE;
+static guint delay_arg = 0;
 
 /* Options */
+static gboolean noninteractive_clipboard_arg = FALSE;
 static gboolean take_window_shot = FALSE;
 static gboolean take_area_shot = FALSE;
 static gboolean include_border = FALSE;
@@ -117,21 +120,17 @@ static GtkWidget *effect_label = NULL;
 static GtkWidget *effects_vbox = NULL;
 static GtkWidget *delay_hbox = NULL;
 
+void loop_dialog_screenshot ();
+
 static void
 display_help (GtkWindow *parent)
 {
   GError *error = NULL;
 
-#if GTK_CHECK_VERSION (3, 22, 0)
   gtk_show_uri_on_window (parent,
                           "help:mate-user-guide/goseditmainmenu-53",
                           gtk_get_current_event_time (),
                           &error);
-#else
-  gtk_show_uri (gtk_window_get_screen (parent),
-		"help:mate-user-guide/goseditmainmenu-53",
-		gtk_get_current_event_time (), &error);
-#endif
 
   if (error)
     {
@@ -335,12 +334,8 @@ create_effects_frame (GtkWidget   *outer_vbox,
   title = g_strconcat ("<b>", frame_title, "</b>", NULL);
   label = gtk_label_new (title);
   gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-#if GTK_CHECK_VERSION (3, 16, 0)
   gtk_label_set_xalign (GTK_LABEL (label), 0.0);
   gtk_label_set_yalign (GTK_LABEL (label), 0.5);
-#else
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-#endif
   gtk_box_pack_start (GTK_BOX (main_vbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
   g_free (title);
@@ -381,12 +376,8 @@ create_effects_frame (GtkWidget   *outer_vbox,
 
   label = gtk_label_new_with_mnemonic (_("Apply _effect:"));
   gtk_widget_set_sensitive (label, take_window_shot);
-#if GTK_CHECK_VERSION (3, 16, 0)
   gtk_label_set_xalign (GTK_LABEL (label), 0.0);
   gtk_label_set_yalign (GTK_LABEL (label), 0.5);
-#else
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-#endif
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
   effect_label = label;
@@ -419,12 +410,8 @@ create_screenshot_frame (GtkWidget   *outer_vbox,
   title = g_strconcat ("<b>", frame_title, "</b>", NULL);
   label = gtk_label_new (title);
   gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-#if GTK_CHECK_VERSION (3, 16, 0)
   gtk_label_set_xalign (GTK_LABEL (label), 0.0);
   gtk_label_set_yalign (GTK_LABEL (label), 0.5);
-#else
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-#endif
   gtk_box_pack_start (GTK_BOX (main_vbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
   g_free (title);
@@ -490,12 +477,8 @@ create_screenshot_frame (GtkWidget   *outer_vbox,
    * delay of <spin button> seconds".
    */
   label = gtk_label_new_with_mnemonic (_("Grab _after a delay of"));
-#if GTK_CHECK_VERSION (3, 16, 0)
   gtk_label_set_xalign (GTK_LABEL (label), 0.0);
   gtk_label_set_yalign (GTK_LABEL (label), 0.5);
-#else
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-#endif
   gtk_box_pack_start (GTK_BOX (delay_hbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
 
@@ -515,12 +498,8 @@ create_screenshot_frame (GtkWidget   *outer_vbox,
    * delay of <spin button> seconds".
    */
   label = gtk_label_new (_("seconds"));
-#if GTK_CHECK_VERSION (3, 16, 0)
   gtk_label_set_xalign (GTK_LABEL (label), 0.0);
   gtk_label_set_yalign (GTK_LABEL (label), 0.5);
-#else
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-#endif
   gtk_box_pack_end (GTK_BOX (delay_hbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
 }
@@ -548,8 +527,8 @@ create_interactive_dialog (void)
   create_screenshot_frame (main_vbox, _("Take Screenshot"));
   create_effects_frame (main_vbox, _("Effects"));
   gtk_dialog_add_buttons (GTK_DIALOG (retval),
-                          GTK_STOCK_HELP, GTK_RESPONSE_HELP,
-                          GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                          "gtk-help", GTK_RESPONSE_HELP,
+                          "gtk-cancel", GTK_RESPONSE_CANCEL,
                           _("Take _Screenshot"), GTK_RESPONSE_OK,
                           NULL);
   gtk_dialog_set_default_response (GTK_DIALOG (retval), GTK_RESPONSE_OK);
@@ -726,6 +705,14 @@ save_done_notification (gpointer data)
     }
 }
 
+static void
+save_screenshot_in_clipboard (GdkDisplay *display, GdkPixbuf *screenshot)
+{
+  GtkClipboard *clipboard =
+    gtk_clipboard_get_for_display (display, GDK_SELECTION_CLIPBOARD);
+  gtk_clipboard_set_image (clipboard, screenshot);
+}
+
 static void
 screenshot_dialog_response_cb (GtkDialog *d,
                                gint response_id,
@@ -737,6 +724,13 @@ screenshot_dialog_response_cb (GtkDialog *d,
     {
       display_help (GTK_WINDOW (d));
     }
+  else if (response_id == SCREENSHOT_RESPONSE_NEW)
+    {
+      gtk_widget_destroy (GTK_WIDGET (d));
+      gtk_main_quit ();
+      interactive_arg = TRUE;
+      loop_dialog_screenshot();
+    }
   else if (response_id == GTK_RESPONSE_OK)
     {
       uri = screenshot_dialog_get_uri (dialog);
@@ -756,13 +750,8 @@ screenshot_dialog_response_cb (GtkDialog *d,
     }
   else if (response_id == SCREENSHOT_RESPONSE_COPY)
     {
-      GtkClipboard *clipboard;
-      GdkPixbuf    *screenshot;
-
-      clipboard = gtk_clipboard_get_for_display (gtk_widget_get_display (GTK_WIDGET (d)),
-                                                 GDK_SELECTION_CLIPBOARD);
-      screenshot = screenshot_dialog_get_screenshot (dialog);
-      gtk_clipboard_set_image (clipboard, screenshot);
+      save_screenshot_in_clipboard (gtk_widget_get_display (GTK_WIDGET (d)),
+                                    screenshot_dialog_get_screenshot (dialog));
     }
   else /* dialog was canceled */
     {
@@ -866,6 +855,14 @@ finish_prepare_screenshot (char *initial_uri, GdkWindow *window, GdkRectangle *r
 
   play_sound_effect (window);
 
+  if (noninteractive_clipboard_arg) {
+    save_screenshot_in_clipboard (gdk_window_get_display (window), screenshot);
+    g_free (initial_uri);
+    /* Done here: */
+    gtk_main_quit ();
+    return;
+  }
+
   dialog = screenshot_dialog_new (screenshot, initial_uri, take_window_shot);
   g_free (initial_uri);
 
@@ -1251,6 +1248,57 @@ screenshooter_init_stock_icons (void)
   g_object_unref (factory);
 }
 
+void
+loop_dialog_screenshot ()
+{
+  /* interactive mode overrides everything */
+  if (interactive_arg)
+    {
+      GtkWidget *dialog;
+      gint response;
+
+      dialog = create_interactive_dialog ();
+      response = gtk_dialog_run (GTK_DIALOG (dialog));
+      gtk_widget_destroy (dialog);
+
+      switch (response)
+        {
+        case GTK_RESPONSE_DELETE_EVENT:
+        case GTK_RESPONSE_CANCEL:
+          return;
+        case GTK_RESPONSE_OK:
+          break;
+        default:
+          g_assert_not_reached ();
+          break;
+        }
+    }
+
+  if (((delay > 0 && interactive_arg) || delay_arg > 0) &&
+      !take_area_shot)
+    {
+      g_timeout_add (delay * 1000,
+		     prepare_screenshot_timeout,
+		     NULL);
+    }
+  else
+    {
+      if (interactive_arg)
+        {
+          /* HACK: give time to the dialog to actually disappear.
+           * We don't have any way to tell when the compositor has finished 
+           * re-drawing.
+           */
+          g_timeout_add (200,
+                         prepare_screenshot_timeout, NULL);
+        }
+      else
+        g_idle_add (prepare_screenshot_timeout, NULL);
+    }
+
+  gtk_main ();
+}
+
 /* main */
 int
 main (int argc, char *argv[])
@@ -1260,15 +1308,14 @@ main (int argc, char *argv[])
   gboolean area_arg = FALSE;
   gboolean include_border_arg = FALSE;
   gboolean disable_border_arg = FALSE;
-  gboolean interactive_arg = FALSE;
   gchar *border_effect_arg = NULL;
   gboolean version_arg = FALSE;
-  guint delay_arg = 0;
   GError *error = NULL;
 
   const GOptionEntry entries[] = {
     { "window", 'w', 0, G_OPTION_ARG_NONE, &window_arg, N_("Grab a window instead of the entire screen"), NULL },
     { "area", 'a', 0, G_OPTION_ARG_NONE, &area_arg, N_("Grab an area of the screen instead of the entire screen"), NULL },
+    { "clipboard", 'c', 0, G_OPTION_ARG_NONE, &noninteractive_clipboard_arg, N_("Send grabbed area directly to the clipboard"), NULL },
     { "include-border", 'b', 0, G_OPTION_ARG_NONE, &include_border_arg, N_("Include the window border with the screenshot"), NULL },
     { "remove-border", 'B', 0, G_OPTION_ARG_NONE, &disable_border_arg, N_("Remove the window border from the screenshot"), NULL },
     { "delay", 'd', 0, G_OPTION_ARG_INT, &delay_arg, N_("Take screenshot after specified delay [in seconds]"), N_("seconds") },
@@ -1305,6 +1352,12 @@ main (int argc, char *argv[])
     exit (EXIT_SUCCESS);
   }
 
+  if (interactive_arg && noninteractive_clipboard_arg) {
+    g_printerr (_("Conflicting options: --clipboard and --interactive should not be "
+                  "used at the same time.\n"));
+    exit (1);
+  }
+
   if (window_arg && area_arg) {
     g_printerr (_("Conflicting options: --window and --area should not be "
                   "used at the same time.\n"));
@@ -1338,52 +1391,7 @@ main (int argc, char *argv[])
   if (delay_arg > 0)
     delay = delay_arg;
 
-  /* interactive mode overrides everything */
-  if (interactive_arg)
-    {
-      GtkWidget *dialog;
-      gint response;
-
-      dialog = create_interactive_dialog ();
-      response = gtk_dialog_run (GTK_DIALOG (dialog));
-      gtk_widget_destroy (dialog);
-
-      switch (response)
-        {
-        case GTK_RESPONSE_DELETE_EVENT:
-        case GTK_RESPONSE_CANCEL:
-          return EXIT_SUCCESS;
-        case GTK_RESPONSE_OK:
-          break;
-        default:
-          g_assert_not_reached ();
-          break;
-        }
-    }
-
-  if (((delay > 0 && interactive_arg) || delay_arg > 0) &&
-      !take_area_shot)
-    {      
-      g_timeout_add (delay * 1000,
-		     prepare_screenshot_timeout,
-		     NULL);
-    }
-  else
-    {
-      if (interactive_arg)
-        {
-          /* HACK: give time to the dialog to actually disappear.
-           * We don't have any way to tell when the compositor has finished 
-           * re-drawing.
-           */
-          g_timeout_add (200,
-                         prepare_screenshot_timeout, NULL);
-        }
-      else
-        g_idle_add (prepare_screenshot_timeout, NULL);
-    }
-
-  gtk_main ();
+  loop_dialog_screenshot();
 
   return EXIT_SUCCESS;
 }
